/*
 * Copyright (C) 2008 Marco Barisione <marco@barisione.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __EMERILLON_CONFIG_KEYS_H__
#define __EMERILLON_CONFIG_KEYS_H__

#define EMERILLON_CONF_DIR                     "/apps/emerillon"

#define EMERILLON_CONF_UI_TOOLBAR              "/apps/emerillon/ui/toolbar"
#define EMERILLON_CONF_UI_STATUSBAR            "/apps/emerillon/ui/statusbar"
#define EMERILLON_CONF_UI_SIDEBAR              "/apps/emerillon/ui/sidebar"
#define EMERILLON_CONF_UI_WINDOW_WIDTH         "/apps/emerillon/ui/window_width"
#define EMERILLON_CONF_UI_WINDOW_HEIGHT        "/apps/emerillon/ui/window_height"
#define EMERILLON_CONF_PLUGINS_ACTIVE_PLUGINS  "/apps/emerillon/plugins/active-plugins"

#endif /* __EMERILLON_CONFIG_KEYS_H__ */
